summaryrefslogtreecommitdiffstats
path: root/bin/reproducible_json.py
diff options
context:
space:
mode:
Diffstat (limited to 'bin/reproducible_json.py')
-rwxr-xr-xbin/reproducible_json.py4
1 files changed, 2 insertions, 2 deletions
diff --git a/bin/reproducible_json.py b/bin/reproducible_json.py
index 4258249c..6d20a6b3 100755
--- a/bin/reproducible_json.py
+++ b/bin/reproducible_json.py
@@ -47,8 +47,8 @@ for row in result:
log.debug(pkg)
output.append(pkg)
- # tracker.d.o should only care about results in unstable
- if pkg['suite'] == 'unstable':
+ # tracker.d.o should only care about results in testing
+ if pkg['suite'] == 'testing':
package = pkg['package']
if package in crossarch: